import { Module } from '@nestjs/common';
import { ConfigModule, ConfigService } from '@nestjs/config';
import { AppController } from './app.controller';
import { AppService } from './app.service';
import { TypeOrmModule } from '@nestjs/typeorm';
import { CarritoModule } from './carrito/carrito.module';
import { DiaModule } from './dia/dia.module';
import { EquipoModule } from './equipo/equipo.module';
import { HoraExcepcionModule } from './hora-excepcion/hora-excepcion.module';
import { InfraccionModule } from './infraccion/infraccion.module';
import { InstitucionModule } from './institucion/institucion.module';
import { InstitucionDiaModule } from './institucion-dia/institucion-dia.module';
import { InstitucionInfraccionModule } from './institucion-infraccion/institucion-infraccion.module';
import { ModuloModule } from './modulo/modulo.module';
import { MotivoModule } from './motivo/motivo.module';
import { MultaModule } from './multa/multa.module';
import { OperadorModule } from './operador/operador.module';
import { PrestamoModule } from './prestamo/prestamo.module';
import { StatusModule } from './status/status.module';
import { TipoCarritoModule } from './tipo-carrito/tipo-carrito.module';
import { TipoUsuarioModule } from './tipo-usuario/tipo-usuario.module';
import { UsuarioModule } from './usuario/usuario.module';

import { Institucion } from './institucion/institucion.entity';
@Module({
  imports: [
    ConfigModule.forRoot({ isGlobal: true }),
    TypeOrmModule.forRootAsync({
      inject: [ConfigService],
      useFactory: (config: ConfigService) => {
        return {
          type: 'mariadb',
          host: config.get<string>('HOST_DB'),
          database: config.get<string>('DB'),
          username: config.get<string>('USER_DB'),
          password: config.get<string>('PASSWORD_DB'),
          synchronize: true,
          entities: [Institucion],
        };
      },
    }),
    CarritoModule,
    DiaModule,
    EquipoModule,
    HoraExcepcionModule,
    InfraccionModule,
    InstitucionModule,
    InstitucionDiaModule,
    InstitucionInfraccionModule,
    ModuloModule,
    MotivoModule,
    MultaModule,
    OperadorModule,
    PrestamoModule,
    StatusModule,
    TipoCarritoModule,
    TipoUsuarioModule,
    UsuarioModule,
  ],
  controllers: [AppController],
  providers: [AppService],
})
export class AppModule {}
